==> haskell-sqlite-simple-0.4.19.0-111.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-J9daIpu6jyNBDZIdTcHL6M
key:                  sqlite-simple-0.4.19.0-J9daIpu6jyNBDZIdTcHL6M
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  d56fdd19d00135706c552b1f1b5e860b
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-J9daIpu6jyNBDZIdTcHL6M
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    blaze-textual-0.2.3.1-FoY2EPiiF1nGiO9F7KrpNI bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-C9orLK2kuLp5WTo5JGwh3M
    exceptions-0.10.7 template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sqlite-simple-0.4.19.0-112-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-5vfJm6muwz0GpIPQ7iB7ck
key:                  sqlite-simple-0.4.19.0-5vfJm6muwz0GpIPQ7iB7ck
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  451ac15f5b4e622ac5d7f900924b5e99
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-5vfJm6muwz0GpIPQ7iB7ck
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    blaze-textual-0.2.3.1-5Xux47dVybF283KdRf2DU7 bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-5YV6VeKmycj6hiQrTX2dT3
    exceptions-0.10.7 template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
